##############################
Keithley 2260B DC Power Supply
##############################

.. autoclass:: pymeasure.instruments.keithley.Keithley2260B
    :members:
    :show-inheritance:
    :inherited-members: CommonBase